get<T> method
Read a synchronous computed on the async graph, recording the dependency.
Implementation
T get<T>(AsyncSlotHandle<T> slot) {
_slot._trackDep(slot);
return slot.get() as T;
}
Read a synchronous computed on the async graph, recording the dependency.
T get<T>(AsyncSlotHandle<T> slot) {
_slot._trackDep(slot);
return slot.get() as T;
}