getAsync<T> method
Await slot's value, recording it as a dependency before the awaited
read.
Implementation
Future<T> getAsync<T>(AsyncSlotHandle<T> slot) async {
_slot._trackDep(slot);
return slot.getAsync();
}
Await slot's value, recording it as a dependency before the awaited
read.
Future<T> getAsync<T>(AsyncSlotHandle<T> slot) async {
_slot._trackDep(slot);
return slot.getAsync();
}