get<T> method
Read a synchronous computed, resolving it inline when dirty.
Implementation
T get<T>(AsyncSlotHandle<T> handle) => handle.get() as T;
Read a synchronous computed, resolving it inline when dirty.
T get<T>(AsyncSlotHandle<T> handle) => handle.get() as T;