AsyncEffectHandle class abstract

Handle for an async effect returned by AsyncContext.effectAsync.

Implemented types

Constructors

AsyncEffectHandle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disposeAsync() Future<void>
Dispose this effect and await its cleanup future.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited