revision property
int
get
revision
The current revision (incremented on each invalidation; a completing future with a stale revision is discarded).
Implementation
int get revision => _revision;
The current revision (incremented on each invalidation; a completing future with a stale revision is discarded).
int get revision => _revision;