computedAsync<T> method
Create a computed async slot owned by this scope.
Implementation
AsyncSlotHandle<T> computedAsync<T>(
Future<T> Function(AsyncComputeContext ctx) compute) =>
adopt(ctx.computedAsync<T>(compute));
Create a computed async slot owned by this scope.
AsyncSlotHandle<T> computedAsync<T>(
Future<T> Function(AsyncComputeContext ctx) compute) =>
adopt(ctx.computedAsync<T>(compute));