BindingCapabilities class

The lazily-dart binding's conformance declaration (protocol.md  Binding Conformance Matrix). This binding implements every MUST layer.

Constructors

BindingCapabilities()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Map<String, Object>
Serialize as the JSON object a peer introspects at build/link time.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

asyncContext → const bool
binding → const String
This binding's name.
capabilityNegotiation → const bool
collections → const bool
crdt → const bool
ffi → const FfiCapability
The ffi capability. host because Dart has dart:ffi; never none (the none carve-out is reserved for platforms with no shared in-process address space, e.g. browser/Worker JS).
ipc → const bool
permissions → const bool
reactiveCore → const bool
stateCharts → const bool
stateMachine → const bool