FfiCapability enum

The ffi capability declaration (protocol.md  C-ABI FFI is required).

Inheritance
Available extensions

Values

host → const FfiCapability

This binding hosts a native C ABI and may be loaded in-process.

const FfiCapability('host')
none → const FfiCapability

This binding's runtime cannot host a native C ABI (e.g. browser/Worker JS). It conforms to the interop contract but NOT the in-process embedding contract, and MUST NOT advertise itself as embeddable.

const FfiCapability('none')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire String
The wire token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FfiCapability>
A constant List of the values in this enum, in order of their declaration.