LazilyFfiClassification class
The result of a frame classification: the status plus (on success) the decoded message kind.
Constructors
- LazilyFfiClassification(LazilyFfiStatus status, LazilyFfiMessageKind kind)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOk → bool
-
Whether classification succeeded.
no setter
- kind → LazilyFfiMessageKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → LazilyFfiStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited