BenchmarkResult class

A single benchmark result.

Constructors

BenchmarkResult(String name, int iterations, int totalMicros)

Properties

avgMicros double
Average time per iteration in microseconds.
no setter
hashCode int
The hash code for this object.
no setterinherited
iterations int
final
name String
final
opsPerSecond double
Operations per second.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalMicros int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited