CommandApplyTerminalConflict class

Inheritance

Constructors

CommandApplyTerminalConflict(String commandId, CommandStatus existing, CommandStatus incoming)
const

Properties

commandId String
final
existing CommandStatus
final
hashCode int
The hash code for this object.
no setteroverride
incoming CommandStatus
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override