CommandCancel class

A cancel frame for a previously-submitted command.

Constructors

CommandCancel({required String commandId, required String causationId, required String source, required int authorityGeneration, String? reason})
const

Properties

authorityGeneration int
final
causationId String
final
commandId String
final
hashCode int
The hash code for this object.
no setterinherited
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Map<String, dynamic>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWire(Object? v) CommandCancel