CommandEvent class

A single command progress event.

Constructors

CommandEvent({required String eventId, required String commandId, required CommandEventKind kind, required int generation, String? detail})
const

Properties

commandId String
final
detail String?
final
eventId String
final
generation int
final
hashCode int
The hash code for this object.
no setterinherited
kind CommandEventKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Map<String, dynamic>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWire(Object? v) CommandEvent