CommandEventKind enum

The kind of a progress event. Terminal-flavored event kinds (cancelled/superseded/timed_out) do not themselves make a command terminal — only the terminal receipt does.

Inheritance
Available extensions

Values

observed → const CommandEventKind
const CommandEventKind('observed')
accepted → const CommandEventKind
const CommandEventKind('accepted')
started → const CommandEventKind
const CommandEventKind('started')
progress → const CommandEventKind
const CommandEventKind('progress')
cancelled → const CommandEventKind
const CommandEventKind('cancelled')
superseded → const CommandEventKind
const CommandEventKind('superseded')
timedOut → const CommandEventKind
const CommandEventKind('timed_out')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWire(String v) CommandEventKind

Constants

values → const List<CommandEventKind>
A constant List of the values in this enum, in order of their declaration.