CommandMessage class sealed

The externally-tagged command message envelope.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encodeJson() String
Encode to a JSON byte string (parity with sibling bindings).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Map<String, dynamic>
Wire form: a single-key object tagging the variant.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodeJson(String data) CommandMessage
fromWire(Object? v) CommandMessage