CommandPolicy class

Per-command behavior policy.

Constructors

CommandPolicy({required DedupePolicy dedupe, required bool supersede, required bool cancelOnPreempt})
const

Properties

cancelOnPreempt bool
final
dedupe DedupePolicy
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supersede bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Map<String, dynamic>

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromWire(Object? v) CommandPolicy