CommandProjectionEntry class
One command's folded projection entry.
Constructors
- CommandProjectionEntry({required String commandId, required CommandStatus status, required bool terminal, required int generation, String? reason, String? terminalReceiptId, String? lastEventId})
-
const
Properties
- commandId → String
-
final
- generation → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastEventId → String?
-
final
- reason → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → CommandStatus
-
final
- terminal → bool
-
final
- terminalReceiptId → String?
-
final
Methods
-
copyWith(
{String? commandId, CommandStatus? status, bool? terminal, int? generation, String? reason, String? terminalReceiptId, String? lastEventId}) → CommandProjectionEntry -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWire(
) → Map< String, dynamic>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override