CommandProjectionImage class

A whole projection image (a checkpoint / reconnect snapshot).

Constructors

CommandProjectionImage({required int generation, required List<CommandProjectionEntry> commands})
const

Properties

commands List<CommandProjectionEntry>
final
generation int
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Map<String, dynamic>

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromWire(Object? v) CommandProjectionImage