CommandSubmit class

A submitted command frame.

Constructors

CommandSubmit({required String commandId, required String causationId, required String source, required String target, required String namespace, required String name, required int authorityGeneration, required String idempotencyKey, required int deadlineMs, required CommandPolicy policy, required String payloadType, required String payloadHash, required IpcValue payload, required List<String> requiredFeatures})
const

Properties

authorityGeneration int
final
causationId String
final
commandId String
final
deadlineMs int
final
hashCode int
The hash code for this object.
no setteroverride
idempotencyKey String
final
name String
final
namespace String
final
payload IpcValue
final
payloadHash String
final
payloadType String
final
policy CommandPolicy
final
requiredFeatures List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
target String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Map<String, dynamic>

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromWire(Object? v) CommandSubmit