DeltaApplyStatusResyncRequired class final

A gap, reorder, or sender restart was detected; request a fresh snapshot.

Inheritance

Constructors

DeltaApplyStatusResyncRequired({required Epoch lastEpoch, required Epoch baseEpoch, required Epoch epoch})
const

Properties

baseEpoch int
final
epoch int
final
hashCode int
The hash code for this object.
no setteroverride
isApply bool
no setterinherited
isResyncRequired bool
no setterinherited
lastEpoch int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override