DeltaOpEdgeAdd class final
New dependency edge.
Constructors
- DeltaOpEdgeAdd(NodeId dependent, NodeId dependency)
-
const
Properties
- dependency → int
-
final
- dependent → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
targetReadable(
PeerPermissions permissions, PeerId peer) → bool -
Whether the
peermay read every node this op names. Ops targeting an unreadable node are omitted from a permission-filtered delta.override -
toString(
) → String -
A string representation of this object.
inherited
-
toWire(
) → Object -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override