IpcValue class sealed

A DeltaOp cell payload (protocol.md  IpcValue).

Externally tagged: {"Inline": [u8]} or {"SharedBlob": ShmBlobRef}.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Object

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWire(Object? value) IpcValue
inline(List<NodeId> bytes) IpcValue
of(Object value) IpcValue
Normalize a List<int] / Uint8List / ShmBlobRef / IpcValue to an IpcValue, matching IpcValue.of in the sibling bindings.
sharedBlob(ShmBlobRef blob) IpcValue