NodeState class sealed

The body of a NodeSnapshot / NodeAdd (protocol.md  NodeState).

Externally tagged: a single-key JSON object whose key is the PascalCase variant name, except NodeStateOpaque which is the bare unit string "Opaque".

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Object
The JSON-shaped, externally-tagged representation.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWire(Object? value) NodeState
Decode an externally-tagged NodeState.
payload(List<NodeId> bytes) NodeState
Convenience constructors mirroring the other bindings.
sharedBlob(ShmBlobRef blob) NodeState

Constants

opaque → const NodeState