NodeStatePayload class final

Concrete serialized value bytes ({"Payload": [u8]}).

Inheritance

Constructors

NodeStatePayload(List<NodeId> bytes)

Properties

bytes Uint8List
The concrete value bytes (a copy of the input, validated to 0..255).
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Object
The JSON-shaped, externally-tagged representation.
override

Operators

operator ==(Object other) bool
The equality operator.
override