RemoteOp class

{ kind: OpKind, node: NodeId }. A read grant never implies write or effect.

Constructors

RemoteOp(OpKind kind, NodeId node)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
kind OpKind
final
node int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

read(NodeId node) RemoteOp
triggerEffect(NodeId node) RemoteOp
write(NodeId node) RemoteOp