ServerIce class

Inheritance

Constructors

ServerIce(int from, String candidate)

Properties

candidate String
final
from int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Map<String, dynamic>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited