SignalingErrorCode enum

Signaling error codes.

Inheritance
Available extensions

Values

badMessage → const SignalingErrorCode
const SignalingErrorCode('bad_message')
notJoined → const SignalingErrorCode
const SignalingErrorCode('not_joined')
alreadyJoined → const SignalingErrorCode
const SignalingErrorCode('already_joined')
duplicatePeer → const SignalingErrorCode
const SignalingErrorCode('duplicate_peer')
unknownTarget → const SignalingErrorCode
const SignalingErrorCode('unknown_target')
permissionDenied → const SignalingErrorCode
const SignalingErrorCode('permission_denied')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SignalingErrorCode>
A constant List of the values in this enum, in order of their declaration.