SignalingRoom class

A signaling room. Transport-agnostic — the caller drives receive / disconnect and delivers the emitted RoutedFrames over the transport.

Constructors

SignalingRoom({SignalingMode mode = SignalingMode.open})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
no setter

Methods

disconnect(Object connId) List<RoutedFrame>
Handle a disconnection. Emits peer-left to all remaining peers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receive(Object connId, ClientMessage message) List<RoutedFrame>
Process an inbound client message. Returns the list of frames to deliver.
roster() List<int>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited