StampFrontierEntry class

A (peer, WireStamp) entry in the per-peer stamp frontier.

On the wire this is a 2-tuple array [peer, stamp] (per schemas/distributed.json#/$defs/StampFrontierEntry, prefixItems), not a {peer, stamp} object — mirrors lazily-rs's Vec<(u64, WireStamp)> serde representation.

Constructors

StampFrontierEntry(PeerId peer, WireStamp stamp)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
peer int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stamp WireStamp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
toWire() List<Object>

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromWire(Object? value) StampFrontierEntry