ResyncActionApply class final

Apply the frame and advance the receiver epoch.

Inheritance

Constructors

ResyncActionApply()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isApply bool
no setterinherited
isIgnore bool
no setterinherited
isRequestSnapshot bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override