ResyncActionIgnore class final

Drop the frame (already-applied re-delivery, malformed, a duplicate request suppressed while resyncing, or a reverse-channel control frame arriving at a data receiver).

Inheritance

Constructors

ResyncActionIgnore()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isApply bool
no setterinherited
isIgnore bool
no setterinherited
isRequestSnapshot bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override