CapabilityCheck class
The result of CapabilityHandshake.checkCompatible.
Constructors
- CapabilityCheck.fail(String field, String reason)
-
Failed handshake —
fieldis the offending handshake field andreasonthe human-readable fail-closed cause.const - CapabilityCheck.ok()
-
Successful handshake.
const
Properties
- field → String?
-
The offending field name on failure, or
nullon success.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isOk → bool
-
no setter
- ok → bool
-
Whether the handshake is compatible.
final
- reason → String?
-
The human-readable fail-closed reason on failure.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited