CommandProjection class
The folded command projection reducer. Mirrors the Rust CommandProjection.
Constructors
Properties
- generation → int
-
The current authority generation.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyMessage(
CommandMessage message) → CommandApplyStatus -
applyProjection(
CommandProjectionImage image) → CommandApplyStatus -
cancel(
CommandCancel cancel) → CommandApplyStatus -
entry(
String commandId) → CommandProjectionEntry? -
The entry for
commandId, ornullif unseen. -
event(
CommandEvent event) → CommandApplyStatus -
hasConflict(
String commandId) → bool -
Whether
commandIdhas a terminal conflict. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
observeReceipt(
CausalReceipt receipt) → CommandApplyStatus -
submit(
CommandSubmit submit) → CommandApplyStatus -
terminalFor(
String commandId) → CommandProjectionEntry? -
The terminal entry for
commandId, ornullif not yet terminal. -
toImage(
) → CommandProjectionImage - The whole projection image (entries sorted by command id).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited