CommandStatus enum
The folded lifecycle status of a command.
Values
- submitted → const CommandStatus
-
const CommandStatus('submitted') - accepted → const CommandStatus
-
const CommandStatus('accepted') - running → const CommandStatus
-
const CommandStatus('running') - applied → const CommandStatus
-
const CommandStatus('applied') - rejected → const CommandStatus
-
const CommandStatus('rejected') - cancelled → const CommandStatus
-
const CommandStatus('cancelled') - superseded → const CommandStatus
-
const CommandStatus('superseded') - timedOut → const CommandStatus
-
const CommandStatus('timed_out')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isTerminal → bool
-
Whether this status is terminal (no further transitions expected).
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wire → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromWire(
String v) → CommandStatus
Constants
-
values
→ const List<
CommandStatus> - A constant List of the values in this enum, in order of their declaration.