DeltaApplyStatusApply class final
The delta was sequential and may be applied; the new epoch is newEpoch.
- Inheritance
-
- Object
- DeltaApplyStatus
- DeltaApplyStatusApply
Constructors
- DeltaApplyStatusApply(Epoch newEpoch)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isApply → bool
-
no setterinherited
- isResyncRequired → bool
-
no setterinherited
- newEpoch → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override