DeltaOpNodeAdd class final
New node (optional wire-stable key).
Constructors
- DeltaOpNodeAdd(NodeId node, String typeTag, NodeState state, {NodeKey? key})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
targetReadable(
PeerPermissions permissions, PeerId peer) → bool -
Whether the
peermay read every node this op names. Ops targeting an unreadable node are omitted from a permission-filtered delta.override -
toString(
) → String -
A string representation of this object.
inherited
-
toWire(
) → Object -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override