ReceiptProjection class
The monotonic ledger view: tracks the latest and terminal receipt per causation id.
Constructors
Properties
- currentGeneration → int
-
The current (highest-observed) generation.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- receiptCount → int
-
The number of tracked receipts.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
containsReceipt(
String receiptId) → bool -
Whether
receiptIdhas been observed. -
latestFor(
String causationId) → CausalReceipt? -
The latest receipt for
causationId, or null. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
observe(
int currentGeneration, CausalReceipt receipt) → ReceiptApplyStatus - Observe a receipt. Returns the apply status.
-
staleReceiptIds(
) → List< String> - Receipt ids whose generation is below the current generation (stale).
-
terminalFor(
String causationId) → CausalReceipt? -
The terminal receipt for
causationId, or null. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited