FileOutbox class
Ready-to-use durable filesystem outbox.
- Inheritance
-
- Object
- StoredOutbox<
FileOutboxStore> - FileOutbox
Constructors
- FileOutbox(String path)
Properties
- ackedThrough → int
-
The highest loaded or observed peer acknowledgement.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store → FileOutboxStore
-
finalinherited
Methods
-
ackThrough(
Epoch epoch) → void -
The peer proved receipt through
epoch; retained frames<= epochMAY be pruned.inherited -
append(
Epoch epoch, IpcMessage msg) → void -
Persist
msgatepochbefore it is handed to the transport.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replayFrom(
Epoch cursor) → List< OutboxFrame> -
Retained frames with
epoch > cursor, in ascending epoch order.inherited -
retainedEpochs(
) → List< Epoch> -
Epochs still retained (not yet acked), ascending — for diagnostics/tests.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited