Transport source for IPC messages. recv returns the next message, or null
when the source is currently exhausted or closed. A read failure is signalled
by throwing (the driver surfaces it as DriverError). Mirrors the
IpcSource trait in lazily-rs/src/ipc.rs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recv(
) → IpcMessage? -
Receive the next IPC message, or
nullif the source is exhausted. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited