ResyncAction class sealed
Receiver decision for an inbound frame (spec  ResyncCoordinator).
Externally the three cases mirror the Rust ResyncAction enum:
ResyncActionApply, ResyncActionRequestSnapshot, ResyncActionIgnore.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isApply → bool
-
no setter
- isIgnore → bool
-
no setter
- isRequestSnapshot → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- apply → const ResyncAction
- Apply the frame and advance the receiver epoch.
- ignore → const ResyncAction
- Drop the frame (re-delivery / malformed / suppressed / control frame).