ResyncActionRequestSnapshot class final
- Inheritance
-
- Object
- ResyncAction
- ResyncActionRequestSnapshot
Constructors
- ResyncActionRequestSnapshot(Epoch fromEpoch)
-
const
Properties
- fromEpoch → int
-
The receiver's current
last_epoch.final - hashCode → int
-
The hash code for this object.
no setteroverride
- isApply → bool
-
no setterinherited
- isIgnore → bool
-
no setterinherited
- isRequestSnapshot → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override